@@ -1,4 +1,4 @@
-//@line 38 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/messageWindow.js"
+//@line 38 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/base/content/messageWindow.js"
 
 /* This is where functions related to the standalone message window are kept */
 
@@ -19,6 +19,7 @@ var gNextMessageViewIndexAfterDelete = -2;
 var gCurrentFolderToRerootForStandAlone;
 var gRerootOnFolderLoadForStandAlone = false;
 var gNextMessageAfterLoad = null;
+var gMessageToLoad = nsMsgKey_None;
 
 // the folderListener object
 var folderListener = {
@@ -139,8 +140,9 @@ nsMsgDBViewCommandUpdater.prototype =
     ClearPendingReadTimer(); // we are loading / selecting a new message so kill the mark as read timer for the currently viewed message
     gCurrentMessageUri = gDBView.URIForFirstSelectedMessage;
     UpdateStandAloneMessageCounts();
-    SetKeywords(aKeywords);
     goUpdateCommand("button_junk");
+    goUpdateCommand("button_goBack");
+    goUpdateCommand("button_goForward");
   },
 
   updateNextMessageAfterDelete : function()
@@ -217,8 +219,9 @@ function OnLoadMessageWindow()
 function delayedOnLoadMessageWindow()
 {
   HideMenus();
+  HideToolbarButtons();
   ShowMenus();
-  AddMailOfflineObserver();
+  MailOfflineMgr.init();
   CreateMailWindowGlobals();
   CreateMessageWindowGlobals();
   verifyAccounts(null);
@@ -251,7 +254,7 @@ function delayedOnLoadMessageWindow()
         messageUri = window.arguments[0];
         if (messageUri instanceof Components.interfaces.nsIURI)
         {
-          loadCustomMessage = /type=x-message-display/.test(messageUri.spec);
+          loadCustomMessage = /type=application\/x-message-display/.test(messageUri.spec);
           gCurrentMessageUri = messageUri.spec;
           if (messageUri instanceof Components.interfaces.nsIMsgMailNewsUrl)
             folder = messageUri.folder;
@@ -281,6 +284,9 @@ function delayedOnLoadMessageWindow()
 
   CreateView(originalView);
   
+  gFindBar.initFindBar();
+  gPhishingDetector.init();
+  
   // initialize the customizeDone method on the customizeable toolbar
   var toolbox = document.getElementById("mail-toolbox");
   toolbox.customizeDone = MailToolboxCustomizeDone;
@@ -291,21 +297,6 @@ function delayedOnLoadMessageWindow()
   setTimeout(OnLoadMessageWindowDelayed, 0, loadCustomMessage);
   
   SetupCommandUpdateHandlers();
-
-  // Ensure the Software Update item is visible on the menubar on Windows and 
-  // Linux, and on the navigation toolbar on MacOSX (since we can't put items on
-  // the menubar on OS X)... 
-  // We don't use a customizable item for the updates item so we can always be
-  // sure it's present.
-  var updateItem = document.getElementById("softwareupdate-item");
-  updateItem.parentNode.removeChild(updateItem);
-//@line 341 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/messageWindow.js"
-  var theToolbar = document.getElementById("toolbar-menubar");
-//@line 343 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/messageWindow.js"
-  if (theToolbar.lastChild.id == "throbber-box")
-    theToolbar.insertBefore(updateItem, document.getElementById("throbber-box"));
-  else
-    theToolbar.appendChild(updateItem);
 }
 
 function OnLoadMessageWindowDelayed(loadCustomMessage)
@@ -393,14 +384,9 @@ function CreateView(originalView)
 function extractMsgKeyFromURI()
 {
   var msgKey = -1;
-  var msgService = messenger.messageServiceFromURI(gCurrentMessageUri);
-  if (msgService)
-  {
-    var msgHdr = msgService.messageURIToMsgHdr(gCurrentMessageUri);
-    if (msgHdr)
-      msgKey = msgHdr.messageKey;
-  }
-
+  var msgHdr =   messenger.msgHdrFromURI(gCurrentMessageUri);
+  if (msgHdr)
+    msgKey = msgHdr.messageKey;
   return msgKey;
 }
 
@@ -411,16 +397,39 @@ function ShowMenus()
     openMail3Pane_menuitem.removeAttribute("hidden");
 }
 
+// Toolbar buttons like quick search and mail views should be hidden for the message window
+function HideToolbarButtons()
+{
+  var mailToolbar = document.getElementById('mail-bar2');
+  if (mailToolbar)
+  {
+    // the quick search box is part of the default toolbar set for the 3-pane and since it is shared code,
+    // the stand alone message window. We need to remove the search-container from the defaultset,
+    // remove the toolbar button itself from the DOM because we've already created it.
+    var defaultSet = mailToolbar.getAttribute("defaultset");
+    defaultSet = defaultSet.replace(/search-container/i, "");
+    mailToolbar.setAttribute('defaultset', defaultSet);
+    
+    var searchContainer = document.getElementById('search-container');
+    if (searchContainer)
+      searchContainer.parentNode.removeChild(searchContainer);
+    
+    // now hack the toolbar palette to remove all of the toolbar items which don't
+    // make sense for the stand alone message window. This prevents them from showing up in the 
+    // customize dialog.
+    var toolbarPalette = document.getElementById('mail-toolbox').palette;
+    toolbarPalette.removeChild(toolbarPalette.getElementsByAttribute('id', 'search-container')[0]);
+    toolbarPalette.removeChild(toolbarPalette.getElementsByAttribute('id', 'mailviews-container')[0]);
+    toolbarPalette.removeChild(toolbarPalette.getElementsByAttribute('id', 'folder-location-container')[0]);    
+  }
+}
+
 function HideMenus()
 {
 	var message_menuitem=document.getElementById('menu_showMessage');
 	if (message_menuitem)
 		message_menuitem.setAttribute("hidden", "true");
 
-	var showSearchToolbar = document.getElementById('menu_showSearchToolbar');
-	if (showSearchToolbar)
-		showSearchToolbar.setAttribute("hidden", "true");
-
 	var showSearch_showMessage_Separator = document.getElementById('menu_showSearch_showMessage_Separator');
 	if (showSearch_showMessage_Separator)
 		showSearch_showMessage_Separator.setAttribute("hidden", "true");
@@ -437,6 +446,10 @@ function HideMenus()
   if (viewLayoutMenu)
     viewLayoutMenu.setAttribute("hidden", "true");
 
+  var viewFolderMenu = document.getElementById("menu_FolderViews");
+  if (viewFolderMenu)
+    viewFolderMenu.setAttribute("hidden", "true");
+
 	var viewMessagesMenu = document.getElementById('viewMessagesMenu');
 	if (viewMessagesMenu)
 		viewMessagesMenu.setAttribute("hidden", "true");
@@ -473,6 +486,13 @@ function HideMenus()
 	if (menuProperties)
 		menuProperties.setAttribute("hidden", "true");
 
+  var favoriteFolder = document.getElementById('menu_favoriteFolder');
+  if (favoriteFolder)
+  {
+    favoriteFolder.disabled = true;
+    favoriteFolder.setAttribute("hidden", "true");
+  }
+
 	var compactFolderMenu = document.getElementById('menu_compactFolder');
 	if (compactFolderMenu)
 		compactFolderMenu.setAttribute("hidden", "true");
@@ -496,6 +516,8 @@ function OnUnloadMessageWindow()
 	OnUnloadMsgHeaderPane();
 
 	OnMailWindowUnload();
+	
+	gFindBar.uninitFindBar();
 }
 
 function CreateMessageWindowGlobals()
@@ -561,10 +583,9 @@ function GetSelectedIndices(dbView)
 
 function GetLoadedMsgFolder()
 {
-	if (gCurrentFolderUri)
-		return RDF.GetResource(gCurrentFolderUri).QueryInterface(Components.interfaces.nsIMsgFolder);
-	else
-    return null;
+  return (gCurrentFolderUri)
+    ? RDF.GetResource(gCurrentFolderUri).QueryInterface(Components.interfaces.nsIMsgFolder)
+    : null;
 }
 
 function GetSelectedFolderURI()
@@ -610,12 +631,16 @@ function SelectFolder(folderUri)
     dbview.close(); 
 
   gCurrentFolderToRerootForStandAlone = folderUri;
-
+  msgWindow.openFolder = msgfolder;
+  
   if (msgfolder.manyHeadersToDownload)
   {
     gRerootOnFolderLoadForStandAlone = true;
     try
     {
+      // accessing the db causes the folder loaded notification to get sent
+      // for local folders.
+      var db = msgfolder.getMsgDatabase(msgWindow);
       msgfolder.startFolderLoading();
       msgfolder.updateFolder(msgWindow);
     }
@@ -643,8 +668,13 @@ function RerootFolderForStandAlone(uri)
   // create new folder view
   CreateView(null);
   
+  if (gMessageToLoad != nsMsgKey_None)
+  {
+    LoadMessageByMsgKey(gMessageToLoad);
+    gMessageToLoad = nsMsgKey_None;
+  }
   // now do the work to load the appropriate message
-  if (gNextMessageAfterLoad) {
+  else if (gNextMessageAfterLoad) {
     var type = gNextMessageAfterLoad;
     gNextMessageAfterLoad = null;
     LoadMessageByNavigationType(type);
@@ -661,7 +691,7 @@ function RerootFolderForStandAlone(uri)
 
 function GetMsgHdrFromUri(messageUri)
 {
-  return messenger.messageServiceFromURI(messageUri).messageURIToMsgHdr(messageUri);
+  return messenger.msgHdrFromURI(messageUri);
 }
 
 function SelectMessage(messageUri)
@@ -704,17 +734,6 @@ var MessageWindowController =
   {
     switch ( command )
     {
-      case "cmd_reply":
-      case "button_reply":
-      case "cmd_replySender":
-      case "cmd_replyGroup":
-      case "cmd_replyall":
-      case "button_replyall":
-      case "cmd_forward":
-      case "button_forward":
-      case "cmd_forwardInline":
-      case "cmd_forwardAttachment":
-      case "cmd_editAsNew":
       case "cmd_delete":
       case "cmd_undo":
       case "cmd_redo":
@@ -727,18 +746,13 @@ var MessageWindowController =
       case "cmd_saveAsTemplate":
       case "cmd_viewPageSource":
       case "cmd_getMsgsForAuthAccounts":
+      case "cmd_tag":
       case "button_mark":
       case "cmd_markAsRead":
       case "cmd_markAllRead":
       case "cmd_markThreadAsRead":
       case "cmd_markReadByDate":
       case "cmd_markAsFlagged":
-      case "cmd_label0":
-      case "cmd_label1":
-      case "cmd_label2":
-      case "cmd_label3":
-      case "cmd_label4":
-      case "cmd_label5":
       case "button_file":
       case "cmd_file":
       case "cmd_markAsJunk":
@@ -756,12 +770,27 @@ var MessageWindowController =
       case "cmd_previousMsg":
       case "cmd_previousUnreadMsg":
       case "cmd_previousFlaggedMsg":
+      case "cmd_goForward":
+      case "cmd_goBack":
+      case "button_goForward":
+      case "button_goBack":
         return !(gDBView.keyForFirstSelectedMessage == nsMsgKey_None);
 
+      case "cmd_reply":
+      case "button_reply":
+      case "cmd_replySender":
+      case "cmd_replyGroup":
+      case "cmd_replyall":
+      case "button_replyall":
+      case "cmd_forward":
+      case "button_forward":
+      case "cmd_forwardInline":
+      case "cmd_forwardAttachment":
+      case "cmd_editAsNew":
       case "cmd_getNextNMessages":
       case "cmd_find":
       case "cmd_findAgain":
-      case "cmd_findPrev":
+      case "cmd_findPrevious":
       case "cmd_search":
       case "cmd_reload":
       case "cmd_getNewMessages":
@@ -774,11 +803,12 @@ var MessageWindowController =
       case "cmd_settingsOffline":
       case "cmd_createFilterFromPopup":
       case "cmd_createFilterFromMenu":
+      case "cmd_moveToFolderAgain":
 				return true;
       case "cmd_synchronizeOffline":
 			case "cmd_downloadFlagged":
 			case "cmd_downloadSelected":
-        return CheckOnline();
+        return MailOfflineMgr.isOnline();
 			default:
 				return false;
 		}
@@ -827,17 +857,12 @@ var MessageWindowController =
 			case "cmd_viewPageSource":
 			case "cmd_reload":
 			case "cmd_find":
+			case "cmd_tag":
       case "button_mark":
 			case "cmd_markAsRead":
 			case "cmd_markAllRead":
 			case "cmd_markThreadAsRead":
       case "cmd_markReadByDate":
-      case "cmd_label0":
-      case "cmd_label1":
-      case "cmd_label2":
-      case "cmd_label3":
-      case "cmd_label4":
-      case "cmd_label5":
         return(true);
 			case "cmd_markAsFlagged":
       case "button_file":
@@ -854,7 +879,7 @@ var MessageWindowController =
 			case "cmd_downloadFlagged":
 			case "cmd_downloadSelected":
       case "cmd_synchronizeOffline":
-                return CheckOnline();
+        return MailOfflineMgr.isOnline();
 			case "cmd_settingsOffline":
                 return IsAccountOfflineEnabled();
 			case "cmd_close":
@@ -867,8 +892,18 @@ var MessageWindowController =
 			case "cmd_previousUnreadMsg":
 				return true;
 			case "cmd_findAgain":
-			case "cmd_findPrev":
-				return MsgCanFindAgain();
+			case "cmd_findPrevious":
+                        case "cmd_goForward":
+                        case "cmd_goBack":
+				return true;
+      case "button_goForward":
+      case "button_goBack":
+      case "cmd_goForward":
+      case "cmd_goBack":
+        return gDBView && 
+            gDBView.navigateStatus((command == "cmd_goBack" || 
+                                    command == "button_goBack") 
+                                    ? nsMsgNavigationType.back : nsMsgNavigationType.forward);
       case "cmd_search":
         var loadedFolder = GetLoadedMsgFolder();
         if (!loadedFolder)
@@ -877,6 +912,8 @@ var MessageWindowController =
       case "cmd_undo":
       case "cmd_redo":
         return SetupUndoRedoCommand(command);
+      case "cmd_moveToFolderAgain":
+        return (pref.getCharPref("mail.last_msg_movecopy_target_uri"));
       case "cmd_applyFilters":
       case "cmd_runJunkControls":
       case "cmd_deleteJunk":
@@ -894,24 +931,24 @@ var MessageWindowController =
 
     var navigationType = nsMsgNavigationType.nextUnreadMessage;
 
-		switch ( command )
-		{
-			case "cmd_close":
-				CloseMailWindow();
-				break;
-			case "cmd_getNewMessages":
-				MsgGetMessage();
-				break;
-            case "cmd_undo":
-                messenger.Undo(msgWindow);
-                break;
-            case "cmd_redo":
-                messenger.Redo(msgWindow);
-                break;
-      case "cmd_getMsgsForAuthAccounts":
-        MsgGetMessagesForAllAuthenticatedAccounts();
-        break;
-			case "cmd_getNextNMessages":
+	switch ( command )
+	{
+		case "cmd_close":
+			CloseMailWindow();
+			break;
+		case "cmd_getNewMessages":
+			MsgGetMessage();
+			break;
+        case "cmd_undo":
+            messenger.Undo(msgWindow);
+            break;
+        case "cmd_redo":
+            messenger.Redo(msgWindow);
+            break;
+        case "cmd_getMsgsForAuthAccounts":
+          MsgGetMessagesForAllAuthenticatedAccounts();
+          break;
+        case "cmd_getNextNMessages":
 				MsgGetNextNMessages();
 				break;
 			case "cmd_reply":
@@ -938,6 +975,13 @@ var MessageWindowController =
 			case "cmd_editAsNew":
 				MsgEditMessageAsNew();
 				break;
+      case "cmd_moveToFolderAgain":
+        var folderId = pref.getCharPref("mail.last_msg_movecopy_target_uri");
+        if (pref.getBoolPref("mail.last_msg_movecopy_was_move"))
+          MsgMoveMessage(folderId);
+        else
+          MsgCopyMessage(folderId);
+        break;				
       case "cmd_createFilterFromPopup":
 				break;// This does nothing because the createfilter is invoked from the popupnode oncommand.        
       case "cmd_createFilterFromMenu":
@@ -982,7 +1026,7 @@ var MessageWindowController =
 			case "cmd_findAgain":
 				MsgFindAgain(false);
 				break;
-			case "cmd_findPrev":
+			case "cmd_findPrevious":
 				MsgFindAgain(true);
 				break;
       case "cmd_search":
@@ -1013,24 +1057,6 @@ var MessageWindowController =
       case "cmd_recalculateJunkScore":
         analyzeMessagesForJunk();
         return;
-      case "cmd_label0":
-        gDBView.doCommand(nsMsgViewCommandType.label0);
- 				return;
-      case "cmd_label1":
-        gDBView.doCommand(nsMsgViewCommandType.label1);
-        return; 
-      case "cmd_label2":
-        gDBView.doCommand(nsMsgViewCommandType.label2);
-        return; 
-      case "cmd_label3":
-        gDBView.doCommand(nsMsgViewCommandType.label3);
-        return; 
-      case "cmd_label4":
-        gDBView.doCommand(nsMsgViewCommandType.label4);
-        return; 
-      case "cmd_label5":
-        gDBView.doCommand(nsMsgViewCommandType.label5);
-        return; 
       case "cmd_downloadFlagged":
         MsgDownloadFlagged();
         return;
@@ -1041,13 +1067,13 @@ var MessageWindowController =
         MsgSynchronizeOffline();
         return;
       case "cmd_settingsOffline":
-        MsgSettingsOffline();
+        MailOfflineMgr.openOfflineAccountSettings();
         return;
       case "cmd_nextUnreadMsg":
       case "button_next":
         performNavigation(nsMsgNavigationType.nextUnreadMessage);
         break;
-			case "cmd_nextUnreadThread":      
+      case "cmd_nextUnreadThread":      
         performNavigation(nsMsgNavigationType.nextUnreadThread);
 				break;
 			case "cmd_nextMsg":
@@ -1060,13 +1086,19 @@ var MessageWindowController =
         performNavigation(nsMsgNavigationType.previousMessage);
 				break;
       case "button_previous":
-			case "cmd_previousUnreadMsg":
+      case "cmd_previousUnreadMsg":
         performNavigation(nsMsgNavigationType.previousUnreadMessage);
-				break;
-			case "cmd_previousFlaggedMsg":
+		break;
+      case "cmd_previousFlaggedMsg":
         performNavigation(nsMsgNavigationType.previousFlagged);
-				break;
-		}
+        break;
+      case "cmd_goForward":
+        performNavigation(nsMsgNavigationType.forward);
+        break;
+      case "cmd_goBack":
+        performNavigation(nsMsgNavigationType.back);
+        break;
+      }
 	},
 	
 	onEvent: function(event)
@@ -1130,3 +1162,17 @@ function LoadMessageByViewIndex(viewIndex)
   if (nsMsgKey_None == gDBView.keyForFirstSelectedMessage)
     UpdateMailToolbar("update toolbar for message Window");
 }
+
+function LoadNavigatedToMessage(msgHdr, folder, folderUri)
+{
+  if (IsCurrentLoadedFolder(folder))
+  {
+    LoadMessageByMsgKey(msgHdr.messageKey);
+  }
+  else
+  {
+    gMessageToLoad = msgHdr.messageKey;
+    SelectFolder(folderUri);
+  }
+}
+
